@@ -42,23 +42,21 @@ class Entity(dict):
 
     .. testsetup:: entity-ctor
 
-        import os
         import uuid
 
         from google.cloud import datastore
-        from tests.system.test_system import Config  # system tests
+        from google.cloud import datastore
 
-        unique = os.getenv('CIRCLE_BUILD_NUM', str(uuid.uuid4())[0:8])
+        unique = str(uuid.uuid4())[0:8]
         client = datastore.Client(namespace='ns{}'.format(unique))
-        key = client.key('EntityKind', 1234, namespace='_Doctest')
-        entity = datastore.Entity(key=key)
-        entity['property'] = 'value'
-        Config.TO_DELETE.append(entity)
 
+        entity = datastore.Entity(client.key('EntityKind', 1234))
+        entity['property'] = 'value'
         client.put(entity)
 
     .. doctest:: entity-ctor
 
+        >>> key = client.key('EntityKind', 1234)
         >>> client.get(key)
         <Entity('EntityKind', 1234) {'property': 'value'}>
 
@@ -70,6 +68,10 @@ class Entity(dict):
         >>> entity['age'] = 20
         >>> entity['name'] = 'JJ'
 
+    .. testcleanup:: entity-ctor
+
+        client.delete(entity.key)
+
     However, not all types are allowed as a value for a Google Cloud Datastore
     entity. The following basic types are supported by the API:
 
