@@ -16,7 +16,7 @@
 from collections import OrderedDict
 import os
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib
@@ -59,7 +59,10 @@ class DatastoreAdminClientMeta(type):
     _transport_registry["grpc"] = DatastoreAdminGrpcTransport
     _transport_registry["grpc_asyncio"] = DatastoreAdminGrpcAsyncIOTransport
 
-    def get_transport_class(cls, label: str = None,) -> Type[DatastoreAdminTransport]:
+    def get_transport_class(
+        cls,
+        label: str = None,
+    ) -> Type[DatastoreAdminTransport]:
         """Returns an appropriate transport class.
 
         Args:
@@ -219,7 +222,9 @@ class DatastoreAdminClient(metaclass=DatastoreAdminClientMeta):
         return self._transport
 
     @staticmethod
-    def common_billing_account_path(billing_account: str,) -> str:
+    def common_billing_account_path(
+        billing_account: str,
+    ) -> str:
         """Returns a fully-qualified billing_account string."""
         return "billingAccounts/{billing_account}".format(
             billing_account=billing_account,
@@ -232,9 +237,13 @@ class DatastoreAdminClient(metaclass=DatastoreAdminClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_folder_path(folder: str,) -> str:
+    def common_folder_path(
+        folder: str,
+    ) -> str:
         """Returns a fully-qualified folder string."""
-        return "folders/{folder}".format(folder=folder,)
+        return "folders/{folder}".format(
+            folder=folder,
+        )
 
     @staticmethod
     def parse_common_folder_path(path: str) -> Dict[str, str]:
@@ -243,9 +252,13 @@ class DatastoreAdminClient(metaclass=DatastoreAdminClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_organization_path(organization: str,) -> str:
+    def common_organization_path(
+        organization: str,
+    ) -> str:
         """Returns a fully-qualified organization string."""
-        return "organizations/{organization}".format(organization=organization,)
+        return "organizations/{organization}".format(
+            organization=organization,
+        )
 
     @staticmethod
     def parse_common_organization_path(path: str) -> Dict[str, str]:
@@ -254,9 +267,13 @@ class DatastoreAdminClient(metaclass=DatastoreAdminClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_project_path(project: str,) -> str:
+    def common_project_path(
+        project: str,
+    ) -> str:
         """Returns a fully-qualified project string."""
-        return "projects/{project}".format(project=project,)
+        return "projects/{project}".format(
+            project=project,
+        )
 
     @staticmethod
     def parse_common_project_path(path: str) -> Dict[str, str]:
@@ -265,10 +282,14 @@ class DatastoreAdminClient(metaclass=DatastoreAdminClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_location_path(project: str, location: str,) -> str:
+    def common_location_path(
+        project: str,
+        location: str,
+    ) -> str:
         """Returns a fully-qualified location string."""
         return "projects/{project}/locations/{location}".format(
-            project=project, location=location,
+            project=project,
+            location=location,
         )
 
     @staticmethod
@@ -447,7 +468,7 @@ class DatastoreAdminClient(metaclass=DatastoreAdminClientMeta):
         request: Union[datastore_admin.ExportEntitiesRequest, dict] = None,
         *,
         project_id: str = None,
-        labels: Dict[str, str] = None,
+        labels: Mapping[str, str] = None,
         entity_filter: datastore_admin.EntityFilter = None,
         output_url_prefix: str = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
@@ -465,7 +486,6 @@ class DatastoreAdminClient(metaclass=DatastoreAdminClientMeta):
         before completion it may leave partial data behind in
         Google Cloud Storage.
 
-
         .. code-block:: python
 
             from google.cloud import datastore_admin_v1
@@ -501,7 +521,7 @@ class DatastoreAdminClient(metaclass=DatastoreAdminClientMeta):
                 This corresponds to the ``project_id`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            labels (Dict[str, str]):
+            labels (Mapping[str, str]):
                 Client-assigned labels.
                 This corresponds to the ``labels`` field
                 on the ``request`` instance; if ``request`` is provided, this
@@ -590,7 +610,12 @@ class DatastoreAdminClient(metaclass=DatastoreAdminClientMeta):
         rpc = self._transport._wrapped_methods[self._transport.export_entities]
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -608,7 +633,7 @@ class DatastoreAdminClient(metaclass=DatastoreAdminClientMeta):
         request: Union[datastore_admin.ImportEntitiesRequest, dict] = None,
         *,
         project_id: str = None,
-        labels: Dict[str, str] = None,
+        labels: Mapping[str, str] = None,
         input_url: str = None,
         entity_filter: datastore_admin.EntityFilter = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
@@ -623,7 +648,6 @@ class DatastoreAdminClient(metaclass=DatastoreAdminClientMeta):
         is possible that a subset of the data has already been
         imported to Cloud Datastore.
 
-
         .. code-block:: python
 
             from google.cloud import datastore_admin_v1
@@ -659,7 +683,7 @@ class DatastoreAdminClient(metaclass=DatastoreAdminClientMeta):
                 This corresponds to the ``project_id`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            labels (Dict[str, str]):
+            labels (Mapping[str, str]):
                 Client-assigned labels.
                 This corresponds to the ``labels`` field
                 on the ``request`` instance; if ``request`` is provided, this
@@ -752,7 +776,12 @@ class DatastoreAdminClient(metaclass=DatastoreAdminClientMeta):
         rpc = self._transport._wrapped_methods[self._transport.import_entities]
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -789,7 +818,6 @@ class DatastoreAdminClient(metaclass=DatastoreAdminClientMeta):
 
         Indexes with a single property cannot be created.
 
-
         .. code-block:: python
 
             from google.cloud import datastore_admin_v1
@@ -844,7 +872,12 @@ class DatastoreAdminClient(metaclass=DatastoreAdminClientMeta):
         rpc = self._transport._wrapped_methods[self._transport.create_index]
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -880,7 +913,6 @@ class DatastoreAdminClient(metaclass=DatastoreAdminClientMeta):
         [delete][google.datastore.admin.v1.DatastoreAdmin.DeleteIndex]
         again.
 
-
         .. code-block:: python
 
             from google.cloud import datastore_admin_v1
@@ -935,7 +967,12 @@ class DatastoreAdminClient(metaclass=DatastoreAdminClientMeta):
         rpc = self._transport._wrapped_methods[self._transport.delete_index]
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -1003,7 +1040,12 @@ class DatastoreAdminClient(metaclass=DatastoreAdminClientMeta):
         rpc = self._transport._wrapped_methods[self._transport.get_index]
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1021,7 +1063,6 @@ class DatastoreAdminClient(metaclass=DatastoreAdminClientMeta):
         the list of indexes and may occasionally return stale
         results.
 
-
         .. code-block:: python
 
             from google.cloud import datastore_admin_v1
@@ -1073,12 +1114,20 @@ class DatastoreAdminClient(metaclass=DatastoreAdminClientMeta):
         rpc = self._transport._wrapped_methods[self._transport.list_indexes]
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__iter__` convenience method.
         response = pagers.ListIndexesPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
