@@ -285,8 +285,7 @@ class DatastoreAdminGrpcTransport(DatastoreAdminTransport):
 
     @property
     def grpc_channel(self) -> grpc.Channel:
-        """Return the channel designed to connect to this service.
-        """
+        """Return the channel designed to connect to this service."""
         return self._grpc_channel
 
     @property
@@ -507,5 +506,9 @@ class DatastoreAdminGrpcTransport(DatastoreAdminTransport):
     def close(self):
         self.grpc_channel.close()
 
+    @property
+    def kind(self) -> str:
+        return "grpc"
+
 
 __all__ = ("DatastoreAdminGrpcTransport",)
