@@ -95,20 +95,24 @@ def test__get_default_mtls_endpoint():
 
 
 @pytest.mark.parametrize(
-    "client_class", [DatastoreAdminClient, DatastoreAdminAsyncClient,]
+    "client_class,transport_name",
+    [
+        (DatastoreAdminClient, "grpc"),
+        (DatastoreAdminAsyncClient, "grpc_asyncio"),
+    ],
 )
-def test_datastore_admin_client_from_service_account_info(client_class):
+def test_datastore_admin_client_from_service_account_info(client_class, transport_name):
     creds = ga_credentials.AnonymousCredentials()
     with mock.patch.object(
         service_account.Credentials, "from_service_account_info"
     ) as factory:
         factory.return_value = creds
         info = {"valid": True}
-        client = client_class.from_service_account_info(info)
+        client = client_class.from_service_account_info(info, transport=transport_name)
         assert client.transport._credentials == creds
         assert isinstance(client, client_class)
 
-        assert client.transport._host == "datastore.googleapis.com:443"
+        assert client.transport._host == ("datastore.googleapis.com:443")
 
 
 @pytest.mark.parametrize(
@@ -137,23 +141,31 @@ def test_datastore_admin_client_service_account_always_use_jwt(
 
 
 @pytest.mark.parametrize(
-    "client_class", [DatastoreAdminClient, DatastoreAdminAsyncClient,]
+    "client_class,transport_name",
+    [
+        (DatastoreAdminClient, "grpc"),
+        (DatastoreAdminAsyncClient, "grpc_asyncio"),
+    ],
 )
-def test_datastore_admin_client_from_service_account_file(client_class):
+def test_datastore_admin_client_from_service_account_file(client_class, transport_name):
     creds = ga_credentials.AnonymousCredentials()
     with mock.patch.object(
         service_account.Credentials, "from_service_account_file"
     ) as factory:
         factory.return_value = creds
-        client = client_class.from_service_account_file("dummy/file/path.json")
+        client = client_class.from_service_account_file(
+            "dummy/file/path.json", transport=transport_name
+        )
         assert client.transport._credentials == creds
         assert isinstance(client, client_class)
 
-        client = client_class.from_service_account_json("dummy/file/path.json")
+        client = client_class.from_service_account_json(
+            "dummy/file/path.json", transport=transport_name
+        )
         assert client.transport._credentials == creds
         assert isinstance(client, client_class)
 
-        assert client.transport._host == "datastore.googleapis.com:443"
+        assert client.transport._host == ("datastore.googleapis.com:443")
 
 
 def test_datastore_admin_client_get_transport_class():
@@ -501,7 +513,9 @@ def test_datastore_admin_client_client_options_scopes(
     client_class, transport_class, transport_name
 ):
     # Check the case scopes are provided.
-    options = client_options.ClientOptions(scopes=["1", "2"],)
+    options = client_options.ClientOptions(
+        scopes=["1", "2"],
+    )
     with mock.patch.object(transport_class, "__init__") as patched:
         patched.return_value = None
         client = client_class(client_options=options, transport=transport_name)
@@ -644,10 +658,17 @@ def test_datastore_admin_client_create_channel_credentials_file(
         )
 
 
-@pytest.mark.parametrize("request_type", [datastore_admin.ExportEntitiesRequest, dict,])
+@pytest.mark.parametrize(
+    "request_type",
+    [
+        datastore_admin.ExportEntitiesRequest,
+        dict,
+    ],
+)
 def test_export_entities(request_type, transport: str = "grpc"):
     client = DatastoreAdminClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -673,7 +694,8 @@ def test_export_entities_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
     client = DatastoreAdminClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc",
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -689,7 +711,8 @@ async def test_export_entities_async(
     transport: str = "grpc_asyncio", request_type=datastore_admin.ExportEntitiesRequest
 ):
     client = DatastoreAdminAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -719,7 +742,9 @@ async def test_export_entities_async_from_dict():
 
 
 def test_export_entities_flattened():
-    client = DatastoreAdminClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = DatastoreAdminClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(type(client.transport.export_entities), "__call__") as call:
@@ -753,7 +778,9 @@ def test_export_entities_flattened():
 
 
 def test_export_entities_flattened_error():
-    client = DatastoreAdminClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = DatastoreAdminClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -826,10 +853,17 @@ async def test_export_entities_flattened_error_async():
         )
 
 
-@pytest.mark.parametrize("request_type", [datastore_admin.ImportEntitiesRequest, dict,])
+@pytest.mark.parametrize(
+    "request_type",
+    [
+        datastore_admin.ImportEntitiesRequest,
+        dict,
+    ],
+)
 def test_import_entities(request_type, transport: str = "grpc"):
     client = DatastoreAdminClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -855,7 +889,8 @@ def test_import_entities_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
     client = DatastoreAdminClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc",
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -871,7 +906,8 @@ async def test_import_entities_async(
     transport: str = "grpc_asyncio", request_type=datastore_admin.ImportEntitiesRequest
 ):
     client = DatastoreAdminAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -901,7 +937,9 @@ async def test_import_entities_async_from_dict():
 
 
 def test_import_entities_flattened():
-    client = DatastoreAdminClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = DatastoreAdminClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(type(client.transport.import_entities), "__call__") as call:
@@ -935,7 +973,9 @@ def test_import_entities_flattened():
 
 
 def test_import_entities_flattened_error():
-    client = DatastoreAdminClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = DatastoreAdminClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -1008,10 +1048,17 @@ async def test_import_entities_flattened_error_async():
         )
 
 
-@pytest.mark.parametrize("request_type", [datastore_admin.CreateIndexRequest, dict,])
+@pytest.mark.parametrize(
+    "request_type",
+    [
+        datastore_admin.CreateIndexRequest,
+        dict,
+    ],
+)
 def test_create_index(request_type, transport: str = "grpc"):
     client = DatastoreAdminClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -1037,7 +1084,8 @@ def test_create_index_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
     client = DatastoreAdminClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc",
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -1053,7 +1101,8 @@ async def test_create_index_async(
     transport: str = "grpc_asyncio", request_type=datastore_admin.CreateIndexRequest
 ):
     client = DatastoreAdminAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -1082,10 +1131,17 @@ async def test_create_index_async_from_dict():
     await test_create_index_async(request_type=dict)
 
 
-@pytest.mark.parametrize("request_type", [datastore_admin.DeleteIndexRequest, dict,])
+@pytest.mark.parametrize(
+    "request_type",
+    [
+        datastore_admin.DeleteIndexRequest,
+        dict,
+    ],
+)
 def test_delete_index(request_type, transport: str = "grpc"):
     client = DatastoreAdminClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -1111,7 +1167,8 @@ def test_delete_index_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
     client = DatastoreAdminClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc",
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -1127,7 +1184,8 @@ async def test_delete_index_async(
     transport: str = "grpc_asyncio", request_type=datastore_admin.DeleteIndexRequest
 ):
     client = DatastoreAdminAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -1156,10 +1214,17 @@ async def test_delete_index_async_from_dict():
     await test_delete_index_async(request_type=dict)
 
 
-@pytest.mark.parametrize("request_type", [datastore_admin.GetIndexRequest, dict,])
+@pytest.mark.parametrize(
+    "request_type",
+    [
+        datastore_admin.GetIndexRequest,
+        dict,
+    ],
+)
 def test_get_index(request_type, transport: str = "grpc"):
     client = DatastoreAdminClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -1196,7 +1261,8 @@ def test_get_index_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
     client = DatastoreAdminClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc",
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -1212,7 +1278,8 @@ async def test_get_index_async(
     transport: str = "grpc_asyncio", request_type=datastore_admin.GetIndexRequest
 ):
     client = DatastoreAdminAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -1252,10 +1319,17 @@ async def test_get_index_async_from_dict():
     await test_get_index_async(request_type=dict)
 
 
-@pytest.mark.parametrize("request_type", [datastore_admin.ListIndexesRequest, dict,])
+@pytest.mark.parametrize(
+    "request_type",
+    [
+        datastore_admin.ListIndexesRequest,
+        dict,
+    ],
+)
 def test_list_indexes(request_type, transport: str = "grpc"):
     client = DatastoreAdminClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -1284,7 +1358,8 @@ def test_list_indexes_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
     client = DatastoreAdminClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc",
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -1300,7 +1375,8 @@ async def test_list_indexes_async(
     transport: str = "grpc_asyncio", request_type=datastore_admin.ListIndexesRequest
 ):
     client = DatastoreAdminAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -1334,7 +1410,8 @@ async def test_list_indexes_async_from_dict():
 
 def test_list_indexes_pager(transport_name: str = "grpc"):
     client = DatastoreAdminClient(
-        credentials=ga_credentials.AnonymousCredentials, transport=transport_name,
+        credentials=ga_credentials.AnonymousCredentials,
+        transport=transport_name,
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -1342,15 +1419,28 @@ def test_list_indexes_pager(transport_name: str = "grpc"):
         # Set the response to a series of pages.
         call.side_effect = (
             datastore_admin.ListIndexesResponse(
-                indexes=[index.Index(), index.Index(), index.Index(),],
+                indexes=[
+                    index.Index(),
+                    index.Index(),
+                    index.Index(),
+                ],
                 next_page_token="abc",
             ),
-            datastore_admin.ListIndexesResponse(indexes=[], next_page_token="def",),
             datastore_admin.ListIndexesResponse(
-                indexes=[index.Index(),], next_page_token="ghi",
+                indexes=[],
+                next_page_token="def",
             ),
             datastore_admin.ListIndexesResponse(
-                indexes=[index.Index(), index.Index(),],
+                indexes=[
+                    index.Index(),
+                ],
+                next_page_token="ghi",
+            ),
+            datastore_admin.ListIndexesResponse(
+                indexes=[
+                    index.Index(),
+                    index.Index(),
+                ],
             ),
             RuntimeError,
         )
@@ -1367,7 +1457,8 @@ def test_list_indexes_pager(transport_name: str = "grpc"):
 
 def test_list_indexes_pages(transport_name: str = "grpc"):
     client = DatastoreAdminClient(
-        credentials=ga_credentials.AnonymousCredentials, transport=transport_name,
+        credentials=ga_credentials.AnonymousCredentials,
+        transport=transport_name,
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -1375,15 +1466,28 @@ def test_list_indexes_pages(transport_name: str = "grpc"):
         # Set the response to a series of pages.
         call.side_effect = (
             datastore_admin.ListIndexesResponse(
-                indexes=[index.Index(), index.Index(), index.Index(),],
+                indexes=[
+                    index.Index(),
+                    index.Index(),
+                    index.Index(),
+                ],
                 next_page_token="abc",
             ),
-            datastore_admin.ListIndexesResponse(indexes=[], next_page_token="def",),
             datastore_admin.ListIndexesResponse(
-                indexes=[index.Index(),], next_page_token="ghi",
+                indexes=[],
+                next_page_token="def",
             ),
             datastore_admin.ListIndexesResponse(
-                indexes=[index.Index(), index.Index(),],
+                indexes=[
+                    index.Index(),
+                ],
+                next_page_token="ghi",
+            ),
+            datastore_admin.ListIndexesResponse(
+                indexes=[
+                    index.Index(),
+                    index.Index(),
+                ],
             ),
             RuntimeError,
         )
@@ -1394,7 +1498,9 @@ def test_list_indexes_pages(transport_name: str = "grpc"):
 
 @pytest.mark.asyncio
 async def test_list_indexes_async_pager():
-    client = DatastoreAdminAsyncClient(credentials=ga_credentials.AnonymousCredentials,)
+    client = DatastoreAdminAsyncClient(
+        credentials=ga_credentials.AnonymousCredentials,
+    )
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
@@ -1403,22 +1509,37 @@ async def test_list_indexes_async_pager():
         # Set the response to a series of pages.
         call.side_effect = (
             datastore_admin.ListIndexesResponse(
-                indexes=[index.Index(), index.Index(), index.Index(),],
+                indexes=[
+                    index.Index(),
+                    index.Index(),
+                    index.Index(),
+                ],
                 next_page_token="abc",
             ),
-            datastore_admin.ListIndexesResponse(indexes=[], next_page_token="def",),
             datastore_admin.ListIndexesResponse(
-                indexes=[index.Index(),], next_page_token="ghi",
+                indexes=[],
+                next_page_token="def",
             ),
             datastore_admin.ListIndexesResponse(
-                indexes=[index.Index(), index.Index(),],
+                indexes=[
+                    index.Index(),
+                ],
+                next_page_token="ghi",
+            ),
+            datastore_admin.ListIndexesResponse(
+                indexes=[
+                    index.Index(),
+                    index.Index(),
+                ],
             ),
             RuntimeError,
         )
-        async_pager = await client.list_indexes(request={},)
+        async_pager = await client.list_indexes(
+            request={},
+        )
         assert async_pager.next_page_token == "abc"
         responses = []
-        async for response in async_pager:
+        async for response in async_pager:  # pragma: no branch
             responses.append(response)
 
         assert len(responses) == 6
@@ -1427,7 +1548,9 @@ async def test_list_indexes_async_pager():
 
 @pytest.mark.asyncio
 async def test_list_indexes_async_pages():
-    client = DatastoreAdminAsyncClient(credentials=ga_credentials.AnonymousCredentials,)
+    client = DatastoreAdminAsyncClient(
+        credentials=ga_credentials.AnonymousCredentials,
+    )
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
@@ -1436,20 +1559,35 @@ async def test_list_indexes_async_pages():
         # Set the response to a series of pages.
         call.side_effect = (
             datastore_admin.ListIndexesResponse(
-                indexes=[index.Index(), index.Index(), index.Index(),],
+                indexes=[
+                    index.Index(),
+                    index.Index(),
+                    index.Index(),
+                ],
                 next_page_token="abc",
             ),
-            datastore_admin.ListIndexesResponse(indexes=[], next_page_token="def",),
             datastore_admin.ListIndexesResponse(
-                indexes=[index.Index(),], next_page_token="ghi",
+                indexes=[],
+                next_page_token="def",
             ),
             datastore_admin.ListIndexesResponse(
-                indexes=[index.Index(), index.Index(),],
+                indexes=[
+                    index.Index(),
+                ],
+                next_page_token="ghi",
+            ),
+            datastore_admin.ListIndexesResponse(
+                indexes=[
+                    index.Index(),
+                    index.Index(),
+                ],
             ),
             RuntimeError,
         )
         pages = []
-        async for page_ in (await client.list_indexes(request={})).pages:
+        async for page_ in (
+            await client.list_indexes(request={})
+        ).pages:  # pragma: no branch
             pages.append(page_)
         for page_, token in zip(pages, ["abc", "def", "ghi", ""]):
             assert page_.raw_page.next_page_token == token
@@ -1462,7 +1600,8 @@ def test_credentials_transport_error():
     )
     with pytest.raises(ValueError):
         client = DatastoreAdminClient(
-            credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+            credentials=ga_credentials.AnonymousCredentials(),
+            transport=transport,
         )
 
     # It is an error to provide a credentials file and a transport instance.
@@ -1482,7 +1621,10 @@ def test_credentials_transport_error():
     options = client_options.ClientOptions()
     options.api_key = "api_key"
     with pytest.raises(ValueError):
-        client = DatastoreAdminClient(client_options=options, transport=transport,)
+        client = DatastoreAdminClient(
+            client_options=options,
+            transport=transport,
+        )
 
     # It is an error to provide an api_key and a credential.
     options = mock.Mock()
@@ -1498,7 +1640,8 @@ def test_credentials_transport_error():
     )
     with pytest.raises(ValueError):
         client = DatastoreAdminClient(
-            client_options={"scopes": ["1", "2"]}, transport=transport,
+            client_options={"scopes": ["1", "2"]},
+            transport=transport,
         )
 
 
@@ -1541,10 +1684,28 @@ def test_transport_adc(transport_class):
         adc.assert_called_once()
 
 
+@pytest.mark.parametrize(
+    "transport_name",
+    [
+        "grpc",
+    ],
+)
+def test_transport_kind(transport_name):
+    transport = DatastoreAdminClient.get_transport_class(transport_name)(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
+    assert transport.kind == transport_name
+
+
 def test_transport_grpc_default():
     # A client should use the gRPC transport by default.
-    client = DatastoreAdminClient(credentials=ga_credentials.AnonymousCredentials(),)
-    assert isinstance(client.transport, transports.DatastoreAdminGrpcTransport,)
+    client = DatastoreAdminClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
+    assert isinstance(
+        client.transport,
+        transports.DatastoreAdminGrpcTransport,
+    )
 
 
 def test_datastore_admin_base_transport_error():
@@ -1588,6 +1749,14 @@ def test_datastore_admin_base_transport():
     with pytest.raises(NotImplementedError):
         transport.operations_client
 
+    # Catch all for all remaining methods and properties
+    remainder = [
+        "kind",
+    ]
+    for r in remainder:
+        with pytest.raises(NotImplementedError):
+            getattr(transport, r)()
+
 
 def test_datastore_admin_base_transport_with_credentials_file():
     # Instantiate the base transport with a credentials file
@@ -1599,7 +1768,8 @@ def test_datastore_admin_base_transport_with_credentials_file():
         Transport.return_value = None
         load_creds.return_value = (ga_credentials.AnonymousCredentials(), None)
         transport = transports.DatastoreAdminTransport(
-            credentials_file="credentials.json", quota_project_id="octopus",
+            credentials_file="credentials.json",
+            quota_project_id="octopus",
         )
         load_creds.assert_called_once_with(
             "credentials.json",
@@ -1744,24 +1914,40 @@ def test_datastore_admin_grpc_transport_client_cert_source_for_mtls(transport_cl
             )
 
 
-def test_datastore_admin_host_no_port():
+@pytest.mark.parametrize(
+    "transport_name",
+    [
+        "grpc",
+        "grpc_asyncio",
+    ],
+)
+def test_datastore_admin_host_no_port(transport_name):
     client = DatastoreAdminClient(
         credentials=ga_credentials.AnonymousCredentials(),
         client_options=client_options.ClientOptions(
             api_endpoint="datastore.googleapis.com"
         ),
+        transport=transport_name,
     )
-    assert client.transport._host == "datastore.googleapis.com:443"
+    assert client.transport._host == ("datastore.googleapis.com:443")
 
 
-def test_datastore_admin_host_with_port():
+@pytest.mark.parametrize(
+    "transport_name",
+    [
+        "grpc",
+        "grpc_asyncio",
+    ],
+)
+def test_datastore_admin_host_with_port(transport_name):
     client = DatastoreAdminClient(
         credentials=ga_credentials.AnonymousCredentials(),
         client_options=client_options.ClientOptions(
             api_endpoint="datastore.googleapis.com:8000"
         ),
+        transport=transport_name,
     )
-    assert client.transport._host == "datastore.googleapis.com:8000"
+    assert client.transport._host == ("datastore.googleapis.com:8000")
 
 
 def test_datastore_admin_grpc_transport_channel():
@@ -1769,7 +1955,8 @@ def test_datastore_admin_grpc_transport_channel():
 
     # Check that channel is used if provided.
     transport = transports.DatastoreAdminGrpcTransport(
-        host="squid.clam.whelk", channel=channel,
+        host="squid.clam.whelk",
+        channel=channel,
     )
     assert transport.grpc_channel == channel
     assert transport._host == "squid.clam.whelk:443"
@@ -1781,7 +1968,8 @@ def test_datastore_admin_grpc_asyncio_transport_channel():
 
     # Check that channel is used if provided.
     transport = transports.DatastoreAdminGrpcAsyncIOTransport(
-        host="squid.clam.whelk", channel=channel,
+        host="squid.clam.whelk",
+        channel=channel,
     )
     assert transport.grpc_channel == channel
     assert transport._host == "squid.clam.whelk:443"
@@ -1890,12 +2078,16 @@ def test_datastore_admin_transport_channel_mtls_with_adc(transport_class):
 
 def test_datastore_admin_grpc_lro_client():
     client = DatastoreAdminClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc",
     )
     transport = client.transport
 
     # Ensure that we have a api-core operations client.
-    assert isinstance(transport.operations_client, operations_v1.OperationsClient,)
+    assert isinstance(
+        transport.operations_client,
+        operations_v1.OperationsClient,
+    )
 
     # Ensure that subsequent calls to the property send the exact same object.
     assert transport.operations_client is transport.operations_client
@@ -1903,12 +2095,16 @@ def test_datastore_admin_grpc_lro_client():
 
 def test_datastore_admin_grpc_lro_async_client():
     client = DatastoreAdminAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc_asyncio",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc_asyncio",
     )
     transport = client.transport
 
     # Ensure that we have a api-core operations client.
-    assert isinstance(transport.operations_client, operations_v1.OperationsAsyncClient,)
+    assert isinstance(
+        transport.operations_client,
+        operations_v1.OperationsAsyncClient,
+    )
 
     # Ensure that subsequent calls to the property send the exact same object.
     assert transport.operations_client is transport.operations_client
@@ -1936,7 +2132,9 @@ def test_parse_common_billing_account_path():
 
 def test_common_folder_path():
     folder = "whelk"
-    expected = "folders/{folder}".format(folder=folder,)
+    expected = "folders/{folder}".format(
+        folder=folder,
+    )
     actual = DatastoreAdminClient.common_folder_path(folder)
     assert expected == actual
 
@@ -1954,7 +2152,9 @@ def test_parse_common_folder_path():
 
 def test_common_organization_path():
     organization = "oyster"
-    expected = "organizations/{organization}".format(organization=organization,)
+    expected = "organizations/{organization}".format(
+        organization=organization,
+    )
     actual = DatastoreAdminClient.common_organization_path(organization)
     assert expected == actual
 
@@ -1972,7 +2172,9 @@ def test_parse_common_organization_path():
 
 def test_common_project_path():
     project = "cuttlefish"
-    expected = "projects/{project}".format(project=project,)
+    expected = "projects/{project}".format(
+        project=project,
+    )
     actual = DatastoreAdminClient.common_project_path(project)
     assert expected == actual
 
@@ -1992,7 +2194,8 @@ def test_common_location_path():
     project = "winkle"
     location = "nautilus"
     expected = "projects/{project}/locations/{location}".format(
-        project=project, location=location,
+        project=project,
+        location=location,
     )
     actual = DatastoreAdminClient.common_location_path(project, location)
     assert expected == actual
@@ -2017,7 +2220,8 @@ def test_client_with_default_client_info():
         transports.DatastoreAdminTransport, "_prep_wrapped_messages"
     ) as prep:
         client = DatastoreAdminClient(
-            credentials=ga_credentials.AnonymousCredentials(), client_info=client_info,
+            credentials=ga_credentials.AnonymousCredentials(),
+            client_info=client_info,
         )
         prep.assert_called_once_with(client_info)
 
@@ -2026,7 +2230,8 @@ def test_client_with_default_client_info():
     ) as prep:
         transport_class = DatastoreAdminClient.get_transport_class()
         transport = transport_class(
-            credentials=ga_credentials.AnonymousCredentials(), client_info=client_info,
+            credentials=ga_credentials.AnonymousCredentials(),
+            client_info=client_info,
         )
         prep.assert_called_once_with(client_info)
 
@@ -2034,7 +2239,8 @@ def test_client_with_default_client_info():
 @pytest.mark.asyncio
 async def test_transport_close_async():
     client = DatastoreAdminAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc_asyncio",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc_asyncio",
     )
     with mock.patch.object(
         type(getattr(client.transport, "grpc_channel")), "close"
